Changelog
=========

For a detailed changelog, please see the `CHANGELOG.md <https://github.com/mexyusef/greenfish/blob/main/CHANGELOG.md>`_ file in the repository.

0.1.0 (2025-06-01)
----------------

* Initial release
* Redfish client implementation
* IPMI client implementation
* Basic UI framework
* System information display
* Hardware inventory view
* Sensor readings display
* Event log viewer
* Firmware update interface
* Connection profile management
* Settings management
